import bb.cascades 1.2
import QTimer 1.0

Container {
    id: tipContainer
    
    signal closing()

    property alias labelText: label.text
    property string tipName: ""
    property bool rotatedLeft: true
    property int rotationZStart: rotatedLeft ? 50 : -50
    property int rotationZEnd: rotatedLeft ? -15 : 15
    rotationZ: rotationZEnd
    scaleX: 0
    scaleY: 0
    property variant tipsShown: _settings.value("tipsShown", [])
    
    maxWidth: _app.deviceInfo.deviceWidth // Will be adjusted by imageLuh
    minWidth: maxWidth
    
    visible: (label.text != "") && (tipsShown.indexOf(tipName) < 0)
    
    onTouch: {
        mainPage.tipTouched = true
        close()
    }
    
    function close() {
        if (scaleX == 1) {
            closing()
            if (tipName != "") {
                var tipsShownList = new Array()
                tipsShownList = _settings.value("tipsShown", [])
                if (tipsShownList.indexOf(tipName) < 0)
                    tipsShownList.push(tipName)
                _settings.setValue("tipsShown", tipsShownList)
            }
            fadeOutAnimation.play()
        }
    }
    
    function showTip() {
        console.log("showTip(), visible: " + visible + " labelText: " + labelText)
        fadeInAnimation.play()
    }
    
    animations: [
        ParallelAnimation {
            id: fadeInAnimation
            delay: 500
            property int duration: 500
            ScaleTransition {
                fromX: 0
                fromY: 0
                toX: 1
                toY: 1
                duration: fadeInAnimation.duration
            }
            RotateTransition {
                fromAngleZ: rotationZStart
                toAngleZ: rotationZEnd
                duration: fadeInAnimation.duration
            }
            onEnded: { dismissTimer.start() }
        },
        ParallelAnimation {
            id: fadeOutAnimation
            property int duration: 500
            ScaleTransition {
                fromX: 1
                fromY: 1
                toX: 0
                toY: 0
                duration: fadeOutAnimation.duration
            }
            RotateTransition {
                fromAngleZ: rotationZEnd
                toAngleZ: rotationZStart
                duration: fadeOutAnimation.duration
            }
            onEnded: { 
                mainPage.tipTouched = false
                if (tipName != "") {
                    tipContainer.destroy()
                }
            }
        }
    ]
    
    attachedObjects: [
        QTimer {
            id: dismissTimer
            interval: (tipName == "") ? 5000 : 10000
            singleShot: true
            onTimeout: { close() }
        }
    ]
    
    layout: DockLayout {}
    
    Container {
        layout: DockLayout {}
        verticalAlignment: VerticalAlignment.Fill
        horizontalAlignment: HorizontalAlignment.Fill
        
        ImageView {
            imageSource: "asset:///Images/PostIt.amd"
            verticalAlignment: VerticalAlignment.Fill
            horizontalAlignment: HorizontalAlignment.Fill
            attachedObjects: [ 
                LayoutUpdateHandler { 
                    id: imageLuh 
                    onLayoutFrameChanged: {
//                        console.log("LayoutFrame: " + layoutFrame.width + " " + layoutFrame.height)
                        if (layoutFrame.width > layoutFrame.height)
                            tipContainer.maxWidth -= _ui.du(1)
                        else {
                            if (tipName != "")
                                tipContainer.showTip()
                        }
                    }
                } 
            ]
        }
        Container {
            leftPadding: 40
            rightPadding: 65
            topPadding: 65
            bottomPadding: 65
            
            Label {
                id: label
                multiline: true
                textStyle.fontSize: FontSize.PointValue
                textStyle.fontSizeValue: _ui.du(0.75)
                textStyle.fontFamily: "Comic Sans MS"
                horizontalAlignment: HorizontalAlignment.Center
            }

            Label {
                text: qsTr("(Touch to close)") + Retranslate.onLocaleOrLanguageChanged
                multiline: true
                textStyle.fontSize: FontSize.XXSmall
                textStyle.fontFamily: "Comic Sans MS"
                horizontalAlignment: HorizontalAlignment.Right
            }
        }
    }
}
