import bb.cascades 1.2
import bb.cascades.places 1.0
import "../CustomElements"

Container {
    layout: DockLayout {}
    horizontalAlignment: HorizontalAlignment.Fill

    topMargin: _ui.du(2)
    bottomMargin: topMargin
    
    topPadding: _ui.du(1)
    bottomPadding: topPadding
    leftPadding: topPadding
    rightPadding: topPadding
            
    background: Color.Black
    Container {
        layout: DockLayout {}
        horizontalAlignment: HorizontalAlignment.Fill

        topPadding: _ui.du(1)
        bottomPadding: topPadding
        leftPadding: topPadding
        rightPadding: topPadding
        
        background: Color.White
        Container {
            horizontalAlignment: HorizontalAlignment.Center
            Label {
                text: qsTr("Weather") + Retranslate.onLocaleOrLanguageChanged
                multiline: true
                textStyle.textAlign: TextAlign.Center
                textStyle.fontSize: FontSize.XLarge
                horizontalAlignment: HorizontalAlignment.Center
            }
            
            Button {
                property string defaultPlaceName: "New York, NY"
                property string defaultPlaceSelected: "40.7127,-74.0059"
                property string placeName: _settings.value("placeName", defaultPlaceName)
                property string placeSelected: _settings.value("placeSelected", defaultPlaceSelected)
                
                onPlaceNameChanged: { _settings.setValue("placeName", placeName) }
                onPlaceSelectedChanged: { _settings.setValue("placeSelected", placeSelected) }

                text: placeName
                imageSource: "asset:///Images/ic_location.png"
                horizontalAlignment: HorizontalAlignment.Center
                onClicked: {
                    var place = picker.show ()
                    if (place) {
                        placeName = place.name
                        placeSelected = place.latitude + "," + place.longitude
                    } else {
                        if (_settings.value("placeSelected", defaultPlaceName) == "") {
                            placeName = defaultPlaceName
                            placeSelected = defaultPlaceSelected
                        }
                    }
                }
                attachedObjects: [ PlacePicker { id: picker } ]
            }
            
            Container {
                layout: StackLayout { orientation: LayoutOrientation.LeftToRight }
                horizontalAlignment: HorizontalAlignment.Center
                Label { text: "°C"; verticalAlignment: VerticalAlignment.Center }
                ImageView {
                    id: imageView1
                    property bool pointingLeft: _settings.value("weatherUseCelsius", false)
                    onPointingLeftChanged: _settings.setValue("weatherUseCelsius", pointingLeft)
                    imageSource: "asset:///Images/ic_arrow.png"
                    rotationZ: pointingLeft ? 0 : 180
                    verticalAlignment: VerticalAlignment.Center
                    minWidth: 96
                    minHeight: minWidth
                    gestureHandlers: TapHandler { onTapped: { imageView1.pointingLeft = !imageView1.pointingLeft } }
                }
                Label { text: "°F"; verticalAlignment: VerticalAlignment.Center }
            }

            Container {
                id: weatherServiceContainer
                property bool resizingLabel: false
                layout: StackLayout { orientation: LayoutOrientation.LeftToRight }
                horizontalAlignment: HorizontalAlignment.Center
                
                function resizeLabel() {
                    if (!resizingLabel) {
                        if ((label1Luh.layoutFrame.width > 0) && (label2Luh.layoutFrame.width > 0)) {
                            resizingLabel = true
                            var largestWidth = Math.max(label1Luh.layoutFrame.width, label2Luh.layoutFrame.width)
                            label1.minWidth = largestWidth
                            label2.minWidth = largestWidth
                        }
                    }
                }
                
                Container {
                    id: label1
                    layout: DockLayout {}
                    verticalAlignment: VerticalAlignment.Center 
                    attachedObjects: [ LayoutUpdateHandler { id: label1Luh; onLayoutFrameChanged: { weatherServiceContainer.resizeLabel() } } ]
                    Label { 
                        text: "Forecast.io"
                        horizontalAlignment: HorizontalAlignment.Right
                    }
                }
                ImageView {
                    id: imageView2
                    property bool pointingLeft: (_settings.value("weatherService", 2) == 2)
                    onPointingLeftChanged: _settings.setValue("weatherService", pointingLeft ? 2 : 0)
                    imageSource: "asset:///Images/ic_arrow.png"
                    rotationZ: pointingLeft ? 0 : 180
                    verticalAlignment: VerticalAlignment.Center
                    minWidth: 96
                    minHeight: minWidth
                    gestureHandlers: TapHandler { onTapped: { imageView2.pointingLeft = !imageView2.pointingLeft } }
                }
                Container {
                    id: label2
                    layout: DockLayout {}
                    verticalAlignment: VerticalAlignment.Center 
                    attachedObjects: [ LayoutUpdateHandler { id: label2Luh; onLayoutFrameChanged: { weatherServiceContainer.resizeLabel() } } ]
                    Label { 
                        text: "OpenWeatherMap"
                        horizontalAlignment: HorizontalAlignment.Left
                    }
                }
            }
        }
    }
}
