import bb.cascades 1.2
import "../CustomElements"

Sheet {
    id: customUriSheet

    property string assignToTrigger
    property alias titleBarTitle: titleBar.title
    property alias firstLabel: firstLabel
    property alias firstTextField: firstTextField
    property alias secondLabel: secondLabel
    property alias secondTextField: secondTextField

    signal acceptActionClicked(string firstTextFieldText, string secondTextFieldText)
    
    onAcceptActionClicked: {
        _assignment.assignCustomUri(customUriSheet.assignToTrigger, firstTextFieldText, secondTextFieldText)
        dooTypeSelectionSheet.close()
    }
    
    onClosed: { destroy() }
    
    peekEnabled: false

    Page {
        titleBar: TitleBar {
            id: titleBar
            dismissAction: ActionItem {
                title: qsTr("Cancel") + Retranslate.onLocaleOrLanguageChanged
                onTriggered: { customUriSheet.close() }
            }
            acceptAction: ActionItem {
                id: acceptAction
                title: qsTr("OK") + Retranslate.onLocaleOrLanguageChanged
                enabled: false
                onTriggered: { 
                    customUriSheet.acceptActionClicked(firstTextField.text, secondTextField.text)
                    customUriSheet.close()
                }
            }
        }
        
        Container {
            id: customUriMainContainer
            layout: DockLayout {}
            horizontalAlignment: HorizontalAlignment.Fill
            verticalAlignment: VerticalAlignment.Fill
            
            attachedObjects: [ LayoutUpdateHandler { id: customUriMainContainerLuh }]

            AnimatedBackground {}
            ScrollView {
                id: scrollview
                scrollRole: ScrollRole.Main
                Container {
                    topPadding: _ui.du(3)
                    bottomPadding: topPadding
                    leftPadding: topPadding
                    rightPadding: topPadding
                    
                    layout: DockLayout {}
                    horizontalAlignment: HorizontalAlignment.Fill
                    verticalAlignment: VerticalAlignment.Fill
                    minWidth: customUriMainContainerLuh.layoutFrame.width
                    minHeight: customUriMainContainerLuh.layoutFrame.height
                    
                    Container {
                        topPadding: _ui.du(1)
                        bottomPadding: topPadding
                        leftPadding: topPadding
                        rightPadding: topPadding
                        
                        horizontalAlignment: HorizontalAlignment.Center
                        verticalAlignment: VerticalAlignment.Center
                        background: Color.Black
                        
                        Container {
                            horizontalAlignment: HorizontalAlignment.Center
                            verticalAlignment: VerticalAlignment.Center
                            background: Color.White
                            
                            topPadding: _ui.du(1)
                            bottomPadding: topPadding
                            leftPadding: topPadding
                            rightPadding: topPadding
                            
                            Container {
                                topMargin: _ui.du(3)
                                bottomMargin: topMargin
                                horizontalAlignment: HorizontalAlignment.Center
                                visible: firstLabel.text != ""
                                Label {
                                    id: firstLabel
                                    multiline: true
                                }
                                TextField {
                                    id: firstTextField
                                    onTextChanging: { acceptAction.enabled = ((firstTextField.text != "") && ((!secondTextFieldContainer.visible) || (secondTextField.text != ""))) }
                                }
                            }
                            Container {
                                id: secondTextFieldContainer
                                topMargin: _ui.du(3)
                                bottomMargin: topMargin
                                horizontalAlignment: HorizontalAlignment.Center
                                visible: ((secondLabel.text != "") && (customUriSheet.assignToTrigger != mainPage.constants.HOMESCREENICON))
                                Label {
                                    id: secondLabel
                                    multiline: true
                                }
                                TextField {
                                    id: secondTextField
                                    onTextChanging: { acceptAction.enabled = ((firstTextField.text != "") && ((!secondTextFieldContainer.visible) || (secondTextField.text != ""))) }
                                }
                            }
                            
                            Container {
                                topMargin: _ui.du(3)
                                bottomMargin: topMargin
                                horizontalAlignment: HorizontalAlignment.Center
                                visible: warningLabel.text != ""
                                Label {
                                    id: warningLabel
                                    text: qsTr("WARNING: This is for advanced users only, setting an invalid URI would make the Homescreen icon undeletable.") + Retranslate.onLocaleOrLanguageChanged
                                    multiline: true
                                    textStyle.fontWeight: FontWeight.Bold
                                    textStyle.fontSize: FontSize.XLarge
                                }
                            }
                        }
                    }
                }
            }
        }
    }
}