import bb.cascades 1.2
import "../CustomElements"
import bb.cascades.pickers 1.0

Sheet {
    id: dooNoteSheet

    /*
    property string assignToTrigger

    signal acceptActionClicked(string firstTextFieldText, string secondTextFieldText)
    
    onAcceptActionClicked: {
        _assignment.assignCustomUri(customUriSheet.assignToTrigger, firstTextFieldText, secondTextFieldText)
        dooTypeSelectionSheet.close()
    }
    */
    
    onOpened: { dooNoteTextArea.requestFocus() }
    onClosed: { destroy() }
    
    peekEnabled: false

    Page {
        id: page
        property string filePath: ""
        onFilePathChanged: {
            if (filePath != "") imageView.pointingLeft = true
        }
        
        titleBar: TitleBar {
            id: titleBar
            title: qsTr("Quick Note")
            dismissAction: ActionItem {
                title: qsTr("Cancel") + Retranslate.onLocaleOrLanguageChanged
                onTriggered: { dooNoteSheet.close() }
            }
            acceptAction: ActionItem {
                id: acceptAction
                title: qsTr("OK") + Retranslate.onLocaleOrLanguageChanged
                enabled: false
                onTriggered: { 
                    var data = new Object()
                    data["note"] = dooNoteTextArea.text
                    data["dooNoteSaveToFile"] = _settings.value("dooNoteSaveToFile", true)
                    data["filePath"] = page.filePath
                    _headlessCommunication.sendMessage("SAVE_NOTE", data)
                    page.filePath = ""
                    dooNoteSheet.close()
                }
            }
        }
        
        Container {
            id: dooNoteMainContainer
            layout: DockLayout {}
            horizontalAlignment: HorizontalAlignment.Fill
            verticalAlignment: VerticalAlignment.Fill
            
            attachedObjects: [ LayoutUpdateHandler { id: dooNoteMainContainerLuh }]

            AnimatedBackground {}
            Container {
                topPadding: _ui.du(3)
                bottomPadding: topPadding
                leftPadding: topPadding
                rightPadding: topPadding
                
                layout: DockLayout {}
                horizontalAlignment: HorizontalAlignment.Fill
                verticalAlignment: VerticalAlignment.Fill
                minWidth: dooNoteMainContainerLuh.layoutFrame.width
                minHeight: dooNoteMainContainerLuh.layoutFrame.height
                
                Container {
                    topPadding: _ui.du(1)
                    bottomPadding: topPadding
                    leftPadding: topPadding
                    rightPadding: topPadding
                    
                    layout: DockLayout {}
                    horizontalAlignment: HorizontalAlignment.Fill
                    verticalAlignment: VerticalAlignment.Fill
                    background: Color.Black
                    
                    Container {
                        id: textAreaParentContainer
                        layout: DockLayout {}
                        horizontalAlignment: HorizontalAlignment.Fill
                        verticalAlignment: VerticalAlignment.Fill
                        background: Color.White
                        
                        topPadding: _ui.du(1)
                        bottomPadding: topPadding
                        leftPadding: topPadding
                        rightPadding: topPadding
                        
                        attachedObjects: [ LayoutUpdateHandler { id: textAreaParentContainerLuh }]
                        
                        Container {
                            horizontalAlignment: HorizontalAlignment.Center
                            verticalAlignment: VerticalAlignment.Center
                            Container {
                                id: saveToContainer
                                property bool resizingLabel: false
                                layout: StackLayout { orientation: LayoutOrientation.LeftToRight }
                                horizontalAlignment: HorizontalAlignment.Center
                                attachedObjects: [ LayoutUpdateHandler { id: saveToContainerLuh }]
                                
                                function resizeLabel() {
                                    if (!resizingLabel) {
                                        if ((label1Luh.layoutFrame.width > 0) && (label2Luh.layoutFrame.width > 0)) {
//                                            resizingLabel = true
                                            var largestWidth = Math.max(label1Luh.layoutFrame.width, label2Luh.layoutFrame.width)
                                            label1.minWidth = largestWidth
                                            label2.minWidth = largestWidth
                                        }
                                    }
                                }
                                
                                Container {
                                    verticalAlignment: VerticalAlignment.Center
                                    rightPadding: _ui.du(3)
                                    Label {
                                        text: qsTr("Save To:") + Retranslate.onLocaleOrLanguageChanged
                                    }
                                }
                                Container {
                                    id: label1
                                    layout: DockLayout {}
                                    verticalAlignment: VerticalAlignment.Center 
                                    attachedObjects: [ LayoutUpdateHandler { id: label1Luh; onLayoutFrameChanged: { saveToContainer.resizeLabel() } } ]
                                    Label { 
                                        text: qsTr("File") + Retranslate.onLocaleOrLanguageChanged
                                        horizontalAlignment: HorizontalAlignment.Right
                                        multiline: true
                                    }
                                }
                                ImageView {
                                    id: imageView
                                    enabled: (page.filePath == "")
                                    opacity: (imageView.enabled ? 1 : 0.2)
                                    property bool pointingLeft: _settings.value("dooNoteSaveToFile", true)
                                    onPointingLeftChanged: _settings.setValue("dooNoteSaveToFile", pointingLeft)
                                    imageSource: "asset:///Images/ic_arrow.png"
                                    rotationZ: pointingLeft ? 0 : 180
                                    verticalAlignment: VerticalAlignment.Center
                                    minWidth: 96
                                    minHeight: minWidth
                                    gestureHandlers: TapHandler { onTapped: { if (imageView.enabled) imageView.pointingLeft = !imageView.pointingLeft } }
                                }
                                Container {
                                    id: label2
                                    layout: DockLayout {}
                                    verticalAlignment: VerticalAlignment.Center 
                                    attachedObjects: [ LayoutUpdateHandler { id: label2Luh; onLayoutFrameChanged: { saveToContainer.resizeLabel() } } ]
                                    Label { 
                                        text: qsTr("Hub") + Retranslate.onLocaleOrLanguageChanged
                                        horizontalAlignment: HorizontalAlignment.Left
                                        multiline: true
                                    }
                                }
                            }
                            
                            TextArea {
                                id: dooNoteTextArea
                                minHeight: textAreaParentContainerLuh.layoutFrame.height - saveToContainerLuh.layoutFrame.height - textAreaParentContainer.topPadding - textAreaParentContainer.bottomPadding
                                maxHeight: minHeight
                                minWidth: textAreaParentContainerLuh.layoutFrame.width - textAreaParentContainer.leftPadding - textAreaParentContainer.rightPadding
                                maxWidth: minWidth
                                focusRetentionPolicyFlags: FocusRetentionPolicy.LoseOnScroll
                                onFocusedChanged: { requestFocus() }
                                onTextChanging: { acceptAction.enabled = (text != "") }
                            }
                        }
                    }
                    
                    Container {
                        visible: !acceptAction.enabled
                        horizontalAlignment: HorizontalAlignment.Left
                        verticalAlignment: VerticalAlignment.Top
                        topPadding: _ui.du(1)
                        leftPadding: topPadding
                        ImageView {
                            imageSource: "asset:///Images/open_doo_note.png"
                            gestureHandlers: [ TapHandler { onTapped: { filePicker.open() } } ]
                            attachedObjects: [
                                FilePicker {
                                    id:filePicker
                                    title : qsTr("Select doo Note") + Retranslate.onLocaleOrLanguageChanged
                                    directories : ["/accounts/1000/shared/misc/doo/notes", "/accounts/1000-enterprise/shared/misc/doo/notes"]
                                    filter: ["*.txt"]
                                    mode: FilePickerMode.Picker
                                    //sourceRestriction: FilePickerSourceRestriction.PathOnly
                                    onFileSelected : {
                                        page.filePath = selectedFiles[0]
                                        var text = _app.loadTextFromFile(page.filePath)
                                        console.log("text: " + text)
                                        dooNoteTextArea.text = text
                                    }
                                }
                            ]
                        }
                    }
                
                }
            }
            
        }
    }
}