import bb.cascades 1.2
import bb.platform 1.2
import bb.system 1.2
import "../CustomElements"

Sheet {
    id: dooTypeSelectionSheet
    
    property string assignToTrigger: ""
    onOpened: {  
        if (assignToTrigger == "") dooTypeSelectionSheet.close() 
        _assignment.assigned.connect(onAssigned)
    }
    onClosed: { destroy() }
    
    signal appSelected(string appId, string appName, string icon)
    
    onAppSelected: { 
        _assignment.assignStartApp(dooTypeSelectionSheet.assignToTrigger, appId, appName, icon)
        dooTypeSelectionSheet.close()
    }

    function onAssigned(map) { close() }
    
    function showContactPicker(dooType, assignToTrigger) {
        _contactManager.pickContact(dooType, assignToTrigger)
        dooTypeSelectionSheet.close()
    }

    peekEnabled: false

    Page {
        titleBar: TitleBar {
            title: qsTr("Select An Action") + Retranslate.onLanguageChanged
            dismissAction: ActionItem {
                title: qsTr("Cancel") + Retranslate.onLocaleOrLanguageChanged
                onTriggered: { dooTypeSelectionSheet.close() }
            }
        }
        
        Container {
            layout: DockLayout {}
            horizontalAlignment: HorizontalAlignment.Fill
            verticalAlignment: VerticalAlignment.Fill
            
            AnimatedBackground {}
            ScrollView {
                id: scrollView
                scrollRole: ScrollRole.Main
                Container {
                    horizontalAlignment: HorizontalAlignment.Center
                    verticalAlignment: VerticalAlignment.Center
                    topPadding: _ui.du(3)
                    bottomPadding: topPadding
                    leftPadding: topPadding
                    rightPadding: topPadding
                    DooTypeTemplate {
                        visible: (dooTypeSelectionSheet.assignToTrigger != mainPage.constants.HOMESCREENICON) && (platformInfo.osVersion.indexOf("10.2") < 0)
                        action: qsTr("Open An Application") + Retranslate.onLocaleOrLanguageChanged
                        description: qsTr("Will open the selected application.") + Retranslate.onLocaleOrLanguageChanged
                        imageSource: "asset:///Images/ic_open.png"
                        dooType: 0
                        onClicked: {
                            var createdControl = appSelectionSheet.createObject(dooTypeSelectionSheet)
                            createdControl.appSelected.connect(dooTypeSelectionSheet.appSelected)
                            createdControl.open()
                        }
                        attachedObjects: [
                            ComponentDefinition {
                                id: appSelectionSheet
                                AppSelectionSheet {
                                    onAppSelected: {
                                        close()
                                    }
                                }
                            },
                            PlatformInfo { id: platformInfo }
                        ]
                    }
                    
                    DooTypeTemplate {
                        action: qsTr("Call someone") + Retranslate.onLocaleOrLanguageChanged
                        description: qsTr("Call a specific contact.") + Retranslate.onLocaleOrLanguageChanged
                        imageSource: "asset:///Images/ic_phone.png"
                        dooType: 1
                        onClicked: { dooTypeSelectionSheet.showContactPicker(dooType, dooTypeSelectionSheet.assignToTrigger) }
                    }
                    
                    /*
                    DooTypeTemplate {
                        action: qsTr("Accept a call") + Retranslate.onLocaleOrLanguageChanged 
                        description: qsTr("Accept an incoming call.") + Retranslate.onLocaleOrLanguageChanged + " (Beta feature)"
                        imageSource: "asset:///Images/ic_phone.png"
                        dooType: 18
                        onClicked: { _assignment.assignAcceptCall(dooTypeSelectionSheet.assignToTrigger, action) }
                    }
                    */
                    
                    DooTypeTemplate {
                        action: qsTr("End a call") + Retranslate.onLocaleOrLanguageChanged
                        description: qsTr("End a call.") + Retranslate.onLocaleOrLanguageChanged
                        imageSource: "asset:///Images/ic_reject_phone.png"
                        dooType: 17
                        onClicked: { _assignment.assignRejectCall(dooTypeSelectionSheet.assignToTrigger, action) }
                    }
                    
                    DooTypeTemplate {
                        action: qsTr("Compose SMS") + Retranslate.onLocaleOrLanguageChanged
                        description: qsTr("Starts an SMS conversation with the selected contact, you'll be able to write the message.") + Retranslate.onLocaleOrLanguageChanged
                        imageSource: "asset:///Images/ic_sms.png"
                        dooType: 2
                        onClicked: { dooTypeSelectionSheet.showContactPicker(dooType, dooTypeSelectionSheet.assignToTrigger) }
                    }
                    
                    DooTypeTemplate {
                        action: qsTr("Compose Email") + Retranslate.onLocaleOrLanguageChanged
                        description: qsTr("Starts an email conversation with the selected contact, you'll be able to write the message.") + Retranslate.onLocaleOrLanguageChanged
                        imageSource: "asset:///Images/ic_email.png"
                        dooType: 3
                        onClicked: { dooTypeSelectionSheet.showContactPicker(dooType, dooTypeSelectionSheet.assignToTrigger) }
                    }
                    
                    DooTypeTemplate {
                        id: composeBbmAction
                        action: qsTr("Compose BBM") + Retranslate.onLocaleOrLanguageChanged
                        description: qsTr("Starts a BBM conversation with the selected contact, you'll be able to write the message.") + Retranslate.onLocaleOrLanguageChanged
                        imageSource: "asset:///Images/ic_start_bbm_chat.png"
                        dooType: 4
                        onClicked: { 
                            bbmPinPrompt.show()
                            
                            /*
                            if (_app.getPerimeterPath().indexOf("1000-enterprise") >= 0) {
                                // Enterprise user
                                bbmPinPrompt.show()
                            }
                            else {
                                dooTypeSelectionSheet.showContactPicker(dooType, dooTypeSelectionSheet.assignToTrigger)
                            }
                            */
                        }
                        attachedObjects: [
                            SystemPrompt {
                                id: bbmPinPrompt
                                title: qsTr("Copy BBM pin") + Retranslate.onLocaleOrLanguageChanged
                                inputField.emptyText: "A1B2C3D4"
                                confirmButton.label: qsTr("OK") + Retranslate.onLocaleOrLanguageChanged
                                cancelButton.label: qsTr("Cancel") + Retranslate.onLocaleOrLanguageChanged
                                onFinished: {
                                    if ((inputFieldTextEntry() != "") && (result == SystemUiResult.ConfirmButtonSelection)) {
                                        bbmNamePrompt.pin = inputFieldTextEntry()
                                        bbmNamePrompt.show()
                                    }
                                }
                            },
                            SystemPrompt {
                                id: bbmNamePrompt
                                property string pin
                                property string name
                                
                                title: qsTr("BBM name") + Retranslate.onLocaleOrLanguageChanged
                                body: qsTr("Name of this BBM contact:") + Retranslate.onLocaleOrLanguageChanged
                                confirmButton.label: qsTr("OK") + Retranslate.onLocaleOrLanguageChanged
                                cancelButton.label: qsTr("Cancel") + Retranslate.onLocaleOrLanguageChanged
                                onFinished: {
                                    if ((inputFieldTextEntry() != "") && (result == SystemUiResult.ConfirmButtonSelection)) {
                                        name = inputFieldTextEntry()
                                        _assignment.assignComposeBbm(dooTypeSelectionSheet.assignToTrigger, pin, name, composeBbmAction.imageSource)
                                    }
                                }
                            }
                        ]
                    }
                    
                    DooTypeTemplate {
                        action: qsTr("Send SMS") + Retranslate.onLocaleOrLanguageChanged
                        description: qsTr("Send a predefined SMS message to a selected contact.") + Retranslate.onLocaleOrLanguageChanged
                        dooType: 5
                        onClicked: { dooTypeSelectionSheet.showContactPicker(dooType, dooTypeSelectionSheet.assignToTrigger) }
                        
                        visible: false
                    }
                    
                    DooTypeTemplate {
                        action: qsTr("Send Email") + Retranslate.onLocaleOrLanguageChanged
                        description: qsTr("Send a predefined email message to a selected contact.") + Retranslate.onLocaleOrLanguageChanged
                        dooType: 6
                        onClicked: { dooTypeSelectionSheet.showContactPicker(dooType, dooTypeSelectionSheet.assignToTrigger) }
                        
                        visible: false
                    }
                    
                    DooTypeTemplate {
                        action: qsTr("Record audio") + Retranslate.onLocaleOrLanguageChanged
                        description: qsTr("Quickly start/stop recording audio of what's happening around you, a blue LED light will be flashing while recording. This feature might be prohibited in your country, please check your local rules before using it.") + Retranslate.onLocaleOrLanguageChanged
                        imageSource: "asset:///Images/ic_microphone.png"
                        dooType: 7
                        onClicked: {
                            _assignment.assignRecord(dooTypeSelectionSheet.assignToTrigger, action)
                        }
                    }
                    
                    DooTypeTemplate {
                        action: qsTr("Flashlight") + Retranslate.onLocaleOrLanguageChanged
                        description: qsTr("Quickly start/stop the flashlight.") + Retranslate.onLocaleOrLanguageChanged
                        imageSource: "asset:///Images/flashlight_icon.png"
                        dooType: 8
                        visible: _flashlight.flashlightAvailableOnDevice
                        onClicked: {
                            _assignment.assignFlashlight(dooTypeSelectionSheet.assignToTrigger, action)
                        }
                        attachedObjects: [ LayoutUpdateHandler { id: flashlightLuh } ]
                    }
                    
                    DooTypeTemplate {
                        action: qsTr("Open a specific Hub account") + Retranslate.onLocaleOrLanguageChanged
                        description: qsTr("Open the Hub to a specific account.") + Retranslate.onLocaleOrLanguageChanged
                        imageSource: "asset:///Images/ic_hub.png"
                        dooType: 9
                        onClicked: { 
                            var createdControl = hubAccountsSheet.createObject(dooTypeSelectionSheet)
                            createdControl.assignToTrigger = dooTypeSelectionSheet.assignToTrigger
                            createdControl.open()
                        }
                    }
                    
                    DooTypeTemplate {
                        action: qsTr("Open a specific Setting") + Retranslate.onLocaleOrLanguageChanged
                        description: qsTr("Open a Settings card to a specific Setting.") + Retranslate.onLocaleOrLanguageChanged
                        imageSource: "asset:///Images/settings_icon.png"
                        dooType: 9
                        onClicked: { 
                            var createdControl = settingsActionsSheet.createObject(dooTypeSelectionSheet)
                            createdControl.assignToTrigger = dooTypeSelectionSheet.assignToTrigger
                            createdControl.open()
                        }
                    }
                    
                    DooTypeTemplate {
                        id: openFolderAction
                        action: qsTr("Open a specific folder") + Retranslate.onLocaleOrLanguageChanged
                        description: qsTr("Open a folder specified by the user.") + Retranslate.onLocaleOrLanguageChanged // + " (Device)"
                        imageSource: "asset:///Images/ic_folder.png"
                        dooType: 9
                        onClicked: { 
                            var isFilePicker = false
                            var isSdCard = false
                            _app.openPicker(isFilePicker, dooTypeSelectionSheet.assignToTrigger, openFolderAction.imageSource, isSdCard)
                        }
                    }
                    
                    /*
                    DooTypeTemplate {
                        id: openSdFolderAction
                        visible: _app.isTenDotThreeThreeOrUp()
                        action: qsTr("Open a specific folder") + Retranslate.onLocaleOrLanguageChanged
                        description: qsTr("Open a folder specified by the user.") + Retranslate.onLocaleOrLanguageChanged + " (SD card)"
                        imageSource: "asset:///Images/ic_folder.png"
                        dooType: 9
                        onClicked: { 
                            var isFilePicker = false
                            var isSdCard = true
                            _app.openPicker(isFilePicker, dooTypeSelectionSheet.assignToTrigger, openFolderAction.imageSource, isSdCard)
                        }
                    }
                    */
                    
                    DooTypeTemplate {
                        id: openFileAction
                        action: qsTr("Open a specific file") + Retranslate.onLocaleOrLanguageChanged
                        description: qsTr("Open a file specified by the user.") + Retranslate.onLocaleOrLanguageChanged //+ " (Device)"
                        imageSource: "asset:///Images/ic_file.png"
                        dooType: 9
                        onClicked: { 
                            var isFilePicker = true
                            var isSdCard = false
                            _app.openPicker(isFilePicker, dooTypeSelectionSheet.assignToTrigger, openFileAction.imageSource, isSdCard)
                        }
                    }
                    
                    /*
                    DooTypeTemplate {
                        id: openSdFileAction
                        visible: _app.isTenDotThreeThreeOrUp()
                        action: qsTr("Open a specific file") + Retranslate.onLocaleOrLanguageChanged
                        description: qsTr("Open a file specified by the user.") + Retranslate.onLocaleOrLanguageChanged + " (SD card)"
                        imageSource: "asset:///Images/ic_file.png"
                        dooType: 9
                        onClicked: { 
                            var isFilePicker = true
                            var isSdCard = true
                            _app.openPicker(isFilePicker, dooTypeSelectionSheet.assignToTrigger, openFileAction.imageSource, isSdCard)
                        }
                    }
                    */
                    
                    DooTypeTemplate {
                        action: qsTr("Change text in Clipboard accessible to paste") + Retranslate.onLocaleOrLanguageChanged
                        description: qsTr("Show a list of text you have copied in Clipboard in the past and allows you to choose one of them to become available to paste right now.") + Retranslate.onLocaleOrLanguageChanged
                        imageSource: "asset:///Images/ic_clipboard.png"
                        dooType: 11
                        onClicked: { 
                            _assignment.assignClipboard(dooTypeSelectionSheet.assignToTrigger)
                        }
                    }
                    
                    DooTypeTemplate {
                        action: qsTr("Weather Forecast") + Retranslate.onLocaleOrLanguageChanged
                        description: qsTr("Show weather forecast for today and tomorrow.") + Retranslate.onLocaleOrLanguageChanged
                        imageSource: "asset:///Images/ic_weather.png"
                        dooType: 12
                        onClicked: { 
                            _assignment.assignWeather(dooTypeSelectionSheet.assignToTrigger, action)
                        }
                    }
                    
                    DooTypeTemplate {
                        id: browserAction
                        action: qsTr("Webpage") + Retranslate.onLocaleOrLanguageChanged
                        description: qsTr("Open a webpage in Browser.") + Retranslate.onLocaleOrLanguageChanged
                        imageSource: "asset:///Images/ic_browser.png"
                        dooType: 9
                        onClicked: {
                            urlPrompt.isPrivateBrowser = false
                            urlPrompt.show() 
                        }
                        attachedObjects: [
                            SystemPrompt {
                                id: urlPrompt
                                property bool isPrivateBrowser: false
                                title: qsTr("Webpage") + Retranslate.onLocaleOrLanguageChanged
                                body: qsTr("Enter the address of the webpage") + Retranslate.onLocaleOrLanguageChanged
                                inputField.emptyText: "http://google.com"
                                inputField.inputMode: SystemUiInputMode.Url
                                confirmButton.label: qsTr("OK") + Retranslate.onLocaleOrLanguageChanged
                                cancelButton.label: qsTr("Cancel") + Retranslate.onLocaleOrLanguageChanged
                                onFinished: {
                                    if ((inputFieldTextEntry() != "") && (result == SystemUiResult.ConfirmButtonSelection)) {
                                        var url = inputFieldTextEntry()
                                        var imageSource = isPrivateBrowser ? privateBrowserAction.imageSource : browserAction.imageSource
                                        _assignment.assignBrowser(dooTypeSelectionSheet.assignToTrigger, url, imageSource, isPrivateBrowser)
                                    }
                                }
                            }
                        ]
                    }
                    
                    DooTypeTemplate {
                        id: privateBrowserAction
                        action: qsTr("Webpage") + Retranslate.onLocaleOrLanguageChanged
                        description: qsTr("Open a webpage in Browser.") + Retranslate.onLocaleOrLanguageChanged + " (Private Mode)"
                        imageSource: "asset:///Images/ca_browser_private.png"
                        dooType: 9
                        onClicked: {
                            urlPrompt.isPrivateBrowser = true
                            urlPrompt.show() 
                        }
                    }
                    
                    DooTypeTemplate {
                        action: qsTr("Quick Note") + Retranslate.onLocaleOrLanguageChanged
                        description: qsTr("Take a quick note and save it either to Hub or to a text file.") + Retranslate.onLocaleOrLanguageChanged
                        imageSource: "asset:///Images/ic_note.png"
                        dooType: 13
                        onClicked: { 
                            _assignment.assignNote(dooTypeSelectionSheet.assignToTrigger, action, imageSource)
                        }
                    }
                    
                    DooTypeTemplate {
                        action: qsTr("Timer") + Retranslate.onLocaleOrLanguageChanged
                        description: qsTr("Start a timer for a specified amount of time.") + Retranslate.onLocaleOrLanguageChanged
                        imageSource: "asset:///Images/ic_timer.png"
                        dooType: 14
                        onClicked: { 
                            var createdControl = timerSheet.createObject(dooTypeSelectionSheet)
                            createdControl.action = action
                            createdControl.assignToTrigger = dooTypeSelectionSheet.assignToTrigger
                            createdControl.imageSource = imageSource
                            createdControl.open()
                        }
                    }
                    
                    DooTypeTemplate {
                        id: notificationProfileAction
                        property variant profiles: []
                        action: qsTr("Notification Profile") + Retranslate.onLocaleOrLanguageChanged
                        description: qsTr("Change Notification Profile.") + Retranslate.onLocaleOrLanguageChanged
                        imageSource: "asset:///Images/ic_notification.png"
                        dooType: 15
                        onClicked: {                             
                            var a = new Array()
                            a.push(qsTr("Cycle through all") + Retranslate.onLocaleOrLanguageChanged)
                            a.push(qsTr("Silent") + Retranslate.onLocaleOrLanguageChanged)
                            a.push(qsTr("Vibrate Only") + Retranslate.onLocaleOrLanguageChanged)
                            a.push(qsTr("Normal") + Retranslate.onLocaleOrLanguageChanged)
                            a.push(qsTr("Phone Calls Only") + Retranslate.onLocaleOrLanguageChanged)
                            a.push(qsTr("Do Not Disturb") + Retranslate.onLocaleOrLanguageChanged)
                            profiles = a
                            
                            console.log("Profiles: " + profiles)
                            profileListDialog.clearList()
                            profileListDialog.appendItem(profiles[0], true, true)
                            profileListDialog.appendItem(profiles[1])
                            profileListDialog.appendItem(profiles[2])
                            profileListDialog.appendItem(profiles[3])
                            profileListDialog.appendItem(profiles[4])
                            profileListDialog.appendItem(profiles[5])

                            profileListDialog.show()
                        }
                        attachedObjects: [
                            SystemListDialog {
                                id: profileListDialog
                                title: qsTr("Choose a Notification Profile") + Retranslate.onLocaleOrLanguageChanged
                                body: qsTr("What Notification Profile to set when this action is triggered?") + Retranslate.onLocaleOrLanguageChanged
                                confirmButton.label: qsTr("OK") + Retranslate.onLocaleOrLanguageChanged
                                cancelButton.label: qsTr("Cancel") + Retranslate.onLocaleOrLanguageChanged
                                onFinished: {
                                    if (result == SystemUiResult.ConfirmButtonSelection) {
                                        var profile = selectedIndices[0]
                                        _assignment.assignNotificationProfile(dooTypeSelectionSheet.assignToTrigger, profile, notificationProfileAction.profiles[profile], notificationProfileAction.imageSource)
                                    }
                                }
                            }
                        ]
                    }
                    
                    DooTypeTemplate {
                        action: qsTr("Open custom URI (advanced users)") + Retranslate.onLocaleOrLanguageChanged
                        description: qsTr("Open a custom URI specified by the user. If you don't know what a custom URI is, this feature is not for you. Some example of a custom URI are:\ngeo:37.786971,-122.399677\nhttp://m.facebook.com\nescreen://\npim:application/vnd.blackberry.hub:23") + Retranslate.onLocaleOrLanguageChanged
                        dooType: 9
                        onClicked: {
                            var createdControl = customUriSheet.createObject(dooTypeSelectionSheet)
                            createdControl.assignToTrigger = dooTypeSelectionSheet.assignToTrigger
                            createdControl.titleBarTitle = qsTr("Set a custom URI") + Retranslate.onLanguageChanged
                            createdControl.firstLabel.text = qsTr("Custom URI:") + Retranslate.onLocaleOrLanguageChanged
                            // createdControl.firstTextField.hintText = "geo:37.786971,-122.399677"
                            createdControl.firstTextField.input.flags = TextInputFlag.AutoCapitalizationOff
                            createdControl.secondLabel.text = qsTr("Name of this custom URI:") + Retranslate.onLocaleOrLanguageChanged
                            // createdControl.secondTextField.hintText = qsTr("Open Maps to WikiMedia Headquarters") + Retranslate.onLocaleOrLanguageChanged
                            createdControl.open()
                        }
                    }
                    
                    DooTypeTemplate {
                        visible: dooTypeSelectionSheet.assignToTrigger != mainPage.constants.HOMESCREENICON
                        action: qsTr("Don't doo anything (reset)") + Retranslate.onLocaleOrLanguageChanged
                        description: qsTr("Remove any action associated with this button trigger.") + Retranslate.onLocaleOrLanguageChanged
                        dooType: -1
                        onClicked: { dooTypeSelectionSheet.appSelected("", "", "") }
                    }
                }
            }
            
            TipTemplateContainer {
                id: dooTypeSelectionSheetTip
                labelText: qsTr("Here's a list of actions available, why not scroll down a bit and choose to assign flashlight action?") + Retranslate.onLocaleOrLanguageChanged
                tipName: "dooTypeSelectionSheetTip"
                rotatedLeft: true
                translationX: _ui.du(10)
                translationY: Number(_app.deviceInfo.deviceHeight) - tipLuh.layoutFrame.height - _ui.du(20)
                attachedObjects: [ LayoutUpdateHandler { id: tipLuh } ]
                onClosing: { scrollView.scrollToPoint(0, flashlightLuh.layoutFrame.y, ScrollAnimation.Smooth) }
            }
        }
    }
}