import bb.cascades 1.2
import bb.multimedia 1.2
import "../CustomElements"

Sheet {
    id: timerSheet

    property string action
    property string assignToTrigger
    property string imageSource

    onClosed: { destroy() }
    
    peekEnabled: false

    Page {
        titleBar: TitleBar {
            id: titleBar
            title: qsTr("Timer")
            dismissAction: ActionItem {
                title: qsTr("Cancel") + Retranslate.onLocaleOrLanguageChanged
                onTriggered: { timerSheet.close() }
            }
            acceptAction: ActionItem {
                id: acceptAction
                title: qsTr("OK") + Retranslate.onLocaleOrLanguageChanged
                enabled: false
                onTriggered: {
                    _assignment.assignTimer(timerSheet.assignToTrigger, timerPicker.seconds, tonePathDropDown.selectedValue, timerTextField.text, timerSheet.imageSource)
                    timerSheet.close()
                }
            }
        }
        
        Container {
            id: timerMainContainer
            layout: DockLayout {}
            horizontalAlignment: HorizontalAlignment.Fill
            verticalAlignment: VerticalAlignment.Fill
            
            attachedObjects: [ LayoutUpdateHandler { id: timerMainContainerLuh }]

            AnimatedBackground {}
            Container {
                topPadding: _ui.du(3)
                bottomPadding: topPadding
                leftPadding: topPadding
                rightPadding: topPadding
                
                layout: DockLayout {}
                horizontalAlignment: HorizontalAlignment.Fill
                verticalAlignment: VerticalAlignment.Fill
                minWidth: timerMainContainerLuh.layoutFrame.width
                minHeight: timerMainContainerLuh.layoutFrame.height
                
                Container {
                    topPadding: _ui.du(1)
                    bottomPadding: topPadding
                    leftPadding: topPadding
                    rightPadding: topPadding
                    
                    layout: DockLayout {}
                    horizontalAlignment: HorizontalAlignment.Center
                    verticalAlignment: VerticalAlignment.Center
                    background: Color.Black
                    
                    Container {
                        id: timerPickerParentContainer
                        layout: DockLayout {}
                        horizontalAlignment: HorizontalAlignment.Center
                        verticalAlignment: VerticalAlignment.Center
                        background: Color.White
                        
                        topPadding: _ui.du(1)
                        bottomPadding: topPadding
                        leftPadding: topPadding
                        rightPadding: topPadding
                        
                        attachedObjects: [ LayoutUpdateHandler { id: timerPickerParentContainerLuh }]
                        
                        Container {
                            horizontalAlignment: HorizontalAlignment.Center
                            verticalAlignment: VerticalAlignment.Center
                            DateTimePicker {
                                id: timerPicker
                                property int seconds: 0
                                title: qsTr("Duration") + Retranslate.onLocaleOrLanguageChanged
                                mode: DateTimePickerMode.Timer
                                onValueChanged: {
                                    seconds = (value.getHours() * 3600) + (value.getMinutes() * 60) + value.getSeconds()
                                    console.log(seconds)
                                    acceptAction.enabled = ((timerPicker.seconds > 0) && (tonePathDropDown.selectedValue != "") && (timerTextField.text != ""))
                                }
                            }
                            Container {
                                layout: StackLayout { orientation: LayoutOrientation.LeftToRight }
                                horizontalAlignment: HorizontalAlignment.Center
                                DropDown {
                                    id: tonePathDropDown
                                    verticalAlignment: VerticalAlignment.Center
                                    title: qsTr("Alarm Tone") + Retranslate.onLanguageChanged
                                    onSelectedOptionChanged: { 
                                        _settings.setValue("timerTone", selectedValue) 
                                        acceptAction.enabled = ((timerPicker.seconds > 0) && (tonePathDropDown.selectedValue != "") && (timerTextField.text != ""))
                                    }
                                    onCreationCompleted: {
                                        var tones = _tones
                                        for (var i = 0; i < tones.length; i++) {
                                            var newOption = emptyOption.createObject(tonePathDropDown)
                                            var tone = tones[i]
                                            newOption.text = tone.substring(tone.lastIndexOf("/") + 1)
                                            newOption.value = tone
                                            tonePathDropDown.add(newOption)
                                        }
                                        var settingsValue = _settings.value("timerTone", "")
                                        for (var i = 0; i < count(); i++) {
                                            if (settingsValue == at(i).value)
                                                setSelectedOption(at(i))
                                        }
                                    }
                                    attachedObjects: [
                                        ComponentDefinition {
                                            id: emptyOption
                                            Option {}
                                        }
                                    ]
                                }
                                
                                ImageButton {
                                    defaultImageSource: player.isPlaying ? "asset:///Images/ic_stop.png" : "asset:///Images/ic_play.png"
                                    enabled: (tonePathDropDown.selectedValue != "")
                                    verticalAlignment: VerticalAlignment.Center
                                    minWidth: _ui.du(10)
                                    maxWidth: minWidth
                                    minHeight: minWidth
                                    maxHeight: minWidth
                                    onClicked: { 
                                        if (player.isPlaying)
                                            player.stop()
                                        else 
                                            player.play()
                                    }
                                    attachedObjects: [
                                        MediaPlayer {
                                            id: player
                                            property bool isPlaying: (mediaState == MediaState.Started)
                                            sourceUrl: "file://" + tonePathDropDown.selectedValue
                                            volume: 100
                                        }
                                    ]
                                }
                            }
                            
                            TextField {
                                id: timerTextField
                                hintText: qsTr("Name Of Timer") + Retranslate.onLocaleOrLanguageChanged
                                onTextChanging: { acceptAction.enabled = ((timerPicker.seconds > 0) && (tonePathDropDown.selectedValue != "") && (timerTextField.text != "")) }
                            }
                        }
                    }
                }
            }
        }
    }
}