/*
 * Copyright (c) 2013-2015 BlackBerry Limited.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import bb.cascades 1.2
import bb.system 1.2
import "Changelog"
import "CustomElements"
import "Sheets"
import "CustomElements/constants.js" as Constants

Page {
    id: mainPage
    
    property variant constants: Constants
    property bool tipTouched: false // Used to avoid false Tapped event when user dismiss a Tip
    onTipTouchedChanged: {
        console.log("tipTouched: " + tipTouched)
    }
    
    onCreationCompleted: {
        Application.menuEnabled = false
        
        // Creates a MultiCover or SceneCover depending on asset selection
        Application.setCover(activeFrame)
        
//        _app.assignTriggerCommandReceived.connect(onAssignTriggerCommandReceived)

        _app.newChangelog.connect(onChangelog)
        _app.dooNoteRequest.connect(onDooNoteRequest)
        _assignment.homescreenIconAdded.connect(onHomescreenIconAdded)
        _assignment.homescreenIconInfoNeeded.connect(onHomescreenIconInfoNeeded)
    }
    
    function onAssignTriggerCommandReceived(command) {
        var createdControl = appSelectionSheet.createObject(mainPage)
        createdControl.open()
    }
    
    function onChangelog(changelog) {
        var createdControl = changelogSheet.createObject(mainPage)
        createdControl.changelogText = changelog
        createdControl.open()
    }
    
    function onDooNoteRequest() {
        var createdControl = dooNoteSheet.createObject(mainPage)
        createdControl.open()
    }
    
    function onHomescreenIconAdded() {
        console.log("main.qml onHomescreenIconAdded()")
        mainPageToastTip.rotatedLeft = !mainPageToastTip.rotatedLeft
        mainPageToastTip.showTip()
    }
    
    function onHomescreenIconInfoNeeded(map) {
        console.log("function onHomescreenIconInfoNeeded(), map: " + JSON.stringify(map))
        homescreenIconSystemPrompt.triggerData = map
        if (map.dooData.uriName != undefined)
            homescreenIconSystemPrompt.inputField.defaultText = map.dooData.uriName
        else if (map.dooData.contactName != undefined)
            homescreenIconSystemPrompt.inputField.defaultText = map.dooData.contactName
        else if (map.dooData.appName != undefined)
            homescreenIconSystemPrompt.inputField.defaultText = map.dooData.appName
        else if (map.dooData.homescreenIconDefaultName != undefined)
            homescreenIconSystemPrompt.inputField.defaultText = map.dooData.homescreenIconDefaultName
        
        homescreenIconSystemPrompt.show()
    }
    
    attachedObjects: [
        AppCover { id: activeFrame },
        ComponentDefinition {  id: aboutSheet; AboutSheet {} },
        ComponentDefinition { 
            id: appSelectionSheet
            AppSelectionSheet { 
                onCreationCompleted: { appSelected.connect(_assignment.openAppAssignment) }
            }
        },
        ComponentDefinition { id: buttonsShortcutsSheet; ButtonsShortcutsSheet {} },
        ComponentDefinition {  id: changelogSheet; ChangelogSheet {} },
        ComponentDefinition {  id: customUriSheet; CustomUriSheet {} },
        ComponentDefinition { 
            id: dooTypeSelectionSheet
            DooTypeSelectionSheet { 
                onCreationCompleted: { appSelected.connect(_assignment.openAppAssignment) }
            }
        },
        ComponentDefinition { id: hubAccountsSheet; HubAccountsSheet {} },
        ComponentDefinition { id: dooNoteSheet; DooNoteSheet {} },
        ComponentDefinition { id: settingsActionsSheet; SettingsActionsSheet {} },
        ComponentDefinition { id: settingsSheet; SettingsSheet {} },
        ComponentDefinition { id: timerSheet; TimerSheet {} },
        SystemPrompt {
            id: homescreenIconSystemPrompt
            property variant triggerData
            
            title: qsTr("Homescreen Icon Name") + Retranslate.onLocaleOrLanguageChanged
            body: qsTr("What name should be shown underneath the icon?") + Retranslate.onLocaleOrLanguageChanged
            onFinished: {
                if ((inputFieldTextEntry() != "") && (result == SystemUiResult.ConfirmButtonSelection)) {
                    _assignment.createHomescreenIcon(triggerData, inputFieldTextEntry(), triggerData.dooData.icon)
                    inputField.defaultText = ""
                }
            }
        },
        SystemToast {
            id: systemToast
            onFinished: { 
                button.resetLabel()
                body = ""
            }
        }
    ]
    
    Container {
        id: mainPageContainer
        
        layout: DockLayout {}
        horizontalAlignment: HorizontalAlignment.Fill
        verticalAlignment: VerticalAlignment.Fill
        
        AnimatedBackground {}
        WhatToDooContainer {}
        
        TipTemplateContainer {
            id: mainPageToastTip
            labelText: qsTr("Icon added to homescreen successfully! Minimize doo and look for your fresh new icon!") + Retranslate.onLocaleOrLanguageChanged
            rotatedLeft: false
            translationX: (Number(_app.deviceInfo.deviceWidth) / 2) - (tipLuh.layoutFrame.width / 2)
            translationY: (Number(_app.deviceInfo.deviceHeight) / 2) - (tipLuh.layoutFrame.height / 2)
            attachedObjects: [ LayoutUpdateHandler { id: tipLuh } ]
        }
    }
}